@@ -135,10 +135,10 @@ class Service:
                         "traefik.http.routers.traefik.rule": "Host(`" + self.url + "`)",
                         "traefik.http.middlewares.compress.compress": "true",
                         "traefik.http.routers.traefik.service": "api@internal",
-                        "traefik.http.middlewares.secured.chain.middlewares": "https-redirect,default-whitelist,default-headers",
+                        "traefik.http.middlewares.secured.chain.middlewares": "https-redirect,default-headers",
                         "traefik.http.middlewares.https-redirect.redirectScheme.scheme": "https",
                         "traefik.http.middlewares.https-redirect.redirectScheme.permanent": "true",
-                        "traefik.http.middlewares.default-whitelist.ipwhitelist.sourceRange": "10.0.0.0/8,192.168.0.0/16,127.0.0.1/32,172.0.0.0/8",
+                        # "traefik.http.middlewares.default-whitelist.ipwhitelist.sourceRange": "10.0.0.0/8,192.168.0.0/16,127.0.0.1/32,172.0.0.0/8",
                         "traefik.http.middlewares.default-headers.headers.frameDeny": "true",
                         "traefik.http.middlewares.default-headers.headers.sslRedirect": "true",
                         "traefik.http.middlewares.default-headers.headers.browserXssFilter": "true",
